@@ -11,6 +11,13 @@ class Address(collections.namedtuple('Address', 'name mailbox host',
     def from_imapclient(cls, addr):
         return cls(name=addr.name, mailbox=addr.mailbox, host=addr.host)
 
+    @classmethod
+    def from_exchangelib(cls, addr):
+        mailbox, _, host = addr.email_address.rpartition('@')
+        return cls(name=addr.name.encode('ascii'),
+                   mailbox=mailbox.encode('ascii'),
+                   host=host.encode('ascii'))
+
     def re_match(self, addr):
         sname, smbox, shost = self
         if sname is None:
@@ -25,6 +32,11 @@ class Address(collections.namedtuple('Address', 'name mailbox host',
                     re.fullmatch(ohost, shost)))
 
 
+class AddressRe(Address):
+    def in_(self, iterable):
+        return any(addr.re_match(self) for addr in iterable)
+
+
 """
 A directory on the mail server made up of the path components of the directory
 """
